=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2011-08-05 10:29:23 +0000
+++ drizzled/cursor.cc	2011-08-08 12:51:19 +0000
@@ -589,27 +589,12 @@
   next_insert_id= 0;
 }
 
-void Cursor::drop_table(const char *)
+void Cursor::drop_table()
 {
   close();
 }
 
-
-/**
-  Performs checks upon the table.
-
-  @param session                thread doing CHECK Table operation
-
-  @retval
-    HA_ADMIN_OK               Successful upgrade
-  @retval
-    HA_ADMIN_NEEDS_UPGRADE    Table has structures requiring upgrade
-  @retval
-    HA_ADMIN_NEEDS_ALTER      Table has structures requiring ALTER Table
-  @retval
-    HA_ADMIN_NOT_IMPLEMENTED
-*/
-int Cursor::ha_check(Session *)
+int Cursor::ha_check(Session*)
 {
   return HA_ADMIN_OK;
 }
@@ -743,11 +728,9 @@
   @sa Cursor::discard_or_import_tablespace()
 */
 
-int
-Cursor::ha_discard_or_import_tablespace(bool discard)
+int Cursor::ha_discard_or_import_tablespace(bool discard)
 {
   setTransactionReadWrite();
-
   return discard_or_import_tablespace(discard);
 }
 
@@ -757,60 +740,58 @@
   @sa Cursor::drop_table()
 */
 
-void
-Cursor::closeMarkForDelete(const char *name)
+void Cursor::closeMarkForDelete()
 {
   setTransactionReadWrite();
-
-  return drop_table(name);
+  return drop_table();
 }
 
 int Cursor::index_next_same(unsigned char *buf, const unsigned char *key, uint32_t keylen)
 {
-  int error;
-  if (!(error=index_next(buf)))
-  {
-    ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
-    unsigned char *save_record_0= NULL;
-    KeyInfo *key_info= NULL;
-    KeyPartInfo *key_part;
-    KeyPartInfo *key_part_end= NULL;
-
-    /*
-      key_cmp_if_same() compares table->getInsertRecord() against 'key'.
-      In parts it uses table->getInsertRecord() directly, in parts it uses
-      field objects with their local pointers into table->getInsertRecord().
-      If 'buf' is distinct from table->getInsertRecord(), we need to move
-      all record references. This is table->getInsertRecord() itself and
-      the field pointers of the fields used in this key.
-    */
-    if (ptrdiff)
-    {
-      save_record_0= getTable()->getInsertRecord();
-      getTable()->record[0]= buf;
-      key_info= getTable()->key_info + active_index;
-      key_part= key_info->key_part;
-      key_part_end= key_part + key_info->key_parts;
-      for (; key_part < key_part_end; key_part++)
-      {
-        assert(key_part->field);
-        key_part->field->move_field_offset(ptrdiff);
-      }
-    }
-
-    if (key_cmp_if_same(getTable(), key, active_index, keylen))
-    {
-      getTable()->status=STATUS_NOT_FOUND;
-      error=HA_ERR_END_OF_FILE;
-    }
-
-    /* Move back if necessary. */
-    if (ptrdiff)
-    {
-      getTable()->record[0]= save_record_0;
-      for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
-        key_part->field->move_field_offset(-ptrdiff);
-    }
+  int error= index_next(buf);
+  if (error)
+    return error;
+
+  ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
+  unsigned char *save_record_0= NULL;
+  KeyInfo *key_info= NULL;
+  KeyPartInfo *key_part;
+  KeyPartInfo *key_part_end= NULL;
+
+  /*
+  key_cmp_if_same() compares table->getInsertRecord() against 'key'.
+  In parts it uses table->getInsertRecord() directly, in parts it uses
+  field objects with their local pointers into table->getInsertRecord().
+  If 'buf' is distinct from table->getInsertRecord(), we need to move
+  all record references. This is table->getInsertRecord() itself and
+  the field pointers of the fields used in this key.
+  */
+  if (ptrdiff)
+  {
+    save_record_0= getTable()->getInsertRecord();
+    getTable()->record[0]= buf;
+    key_info= getTable()->key_info + active_index;
+    key_part= key_info->key_part;
+    key_part_end= key_part + key_info->key_parts;
+    for (; key_part < key_part_end; key_part++)
+    {
+      assert(key_part->field);
+      key_part->field->move_field_offset(ptrdiff);
+    }
+  }
+
+  if (key_cmp_if_same(getTable(), key, active_index, keylen))
+  {
+    getTable()->status=STATUS_NOT_FOUND;
+    error= HA_ERR_END_OF_FILE;
+  }
+
+  /* Move back if necessary. */
+  if (ptrdiff)
+  {
+    getTable()->record[0]= save_record_0;
+    for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
+      key_part->field->move_field_offset(-ptrdiff);
   }
   return error;
 }

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2011-06-23 10:02:30 +0000
+++ drizzled/cursor.h	2011-08-08 12:51:19 +0000
@@ -170,7 +170,7 @@
     get_auto_increment().
   */
   uint64_t next_insert_id;
-  uint64_t getNextInsertId()
+  uint64_t getNextInsertId() const
   {
     return next_insert_id;
   }
@@ -178,7 +178,7 @@
   /**
     Used by SHOW TABLE STATUS to get the current auto_inc from the engine
   */
-  uint64_t getAutoIncrement()
+  uint64_t getAutoIncrement() const
   {
     return stats.auto_increment_value;
   }
@@ -223,10 +223,7 @@
   int updateRecord(const unsigned char * old_data, unsigned char * new_data) __attribute__ ((warn_unused_result));
   int deleteRecord(const unsigned char * buf) __attribute__ ((warn_unused_result));
   void ha_release_auto_increment();
-
-  /** to be actually called to get 'check()' functionality*/
   int ha_check(Session*);
-
   void ha_start_bulk_insert(ha_rows rows);
   int ha_end_bulk_insert();
   int ha_delete_all_rows();
@@ -236,7 +233,7 @@
   int ha_disable_indexes(uint32_t mode);
   int ha_enable_indexes(uint32_t mode);
   int ha_discard_or_import_tablespace(bool discard);
-  void closeMarkForDelete(const char *name);
+  void closeMarkForDelete();
 
   void adjust_next_insert_id_after_explicit_value(uint64_t nr);
   int update_auto_increment();
@@ -603,7 +600,7 @@
     no new engine should ever use it). Right
     now HEAP does rely on it, so we cannot remove it.
   */
-  virtual void drop_table(const char *name);
+  virtual void drop_table();
 };
 
 extern const char *ha_row_type[];

=== modified file 'drizzled/function/find_in_set.cc'
--- drizzled/function/find_in_set.cc	2011-04-20 22:18:30 +0000
+++ drizzled/function/find_in_set.cc	2011-08-08 12:51:19 +0000
@@ -61,8 +61,7 @@
   }
   null_value=0;
 
-  int diff;
-  if ((diff=buffer->length() - find->length()) >= 0)
+  if (buffer->length() >= find->length())  
   {
     my_wc_t wc;
     const charset_info_st * const cs= cmp_collation.collation;
@@ -75,8 +74,7 @@
     while (1)
     {
       int symbol_len;
-      if ((symbol_len= cs->cset->mb_wc(cs, &wc, (unsigned char*) str_end,
-                                       (unsigned char*) real_end)) > 0)
+      if ((symbol_len= cs->cset->mb_wc(cs, &wc, (unsigned char*) str_end, (unsigned char*) real_end)) > 0)
       {
         const char *substr_end= str_end + symbol_len;
         bool is_last_item= (substr_end == real_end);
@@ -100,7 +98,7 @@
                wc == (my_wc_t) separator)
         return (int64_t) ++position;
       else
-        return 0L;
+        return 0;
     }
   }
   return 0;

=== modified file 'drizzled/generator/all_foreign_keys.h'
--- drizzled/generator/all_foreign_keys.h	2011-03-14 05:40:28 +0000
+++ drizzled/generator/all_foreign_keys.h	2011-08-08 12:51:19 +0000
@@ -49,8 +49,7 @@
       do {
         if (foreign_keys_iterator != table_message.fk_constraint_size())
         {
-          const message::Table::ForeignKeyConstraint &fk_constraint(table_message.fk_constraint(foreign_keys_iterator++));
-          return &fk_constraint;
+          return &table_message.fk_constraint(foreign_keys_iterator++);
         }
 
       } while ((table_ptr= all_tables_generator) && table_setup());
@@ -71,8 +70,7 @@
       } while ((table_ptr= all_tables_generator) && table_setup());
     }
 
-    ForeignKeyConstraintPair null_pair;
-    return null_pair;
+    return ForeignKeyConstraintPair();
   }
 };
 

=== modified file 'drizzled/internal/my_symlink2.cc'
--- drizzled/internal/my_symlink2.cc	2011-06-24 15:25:06 +0000
+++ drizzled/internal/my_symlink2.cc	2011-08-08 12:51:19 +0000
@@ -26,38 +26,30 @@
 #include <drizzled/error.h>
 #include <drizzled/internal/m_string.h>
 
-namespace drizzled
-{
-namespace internal
-{
+namespace drizzled {
+namespace internal {
 
 int my_create_with_symlink(const char *linkname, const char *filename,
                            int createflags, int access_flags, myf MyFlags)
 {
-  int file;
-  int tmp_errno;
   /* Test if we should create a link */
-  int create_link;
-  char abs_linkname[FN_REFLEN];
+  bool create_link= false;
   char rp_buff[PATH_MAX];
 
   if (my_disable_symlinks)
   {
     /* Create only the file, not the link and file */
-    create_link= 0;
     if (linkname)
       filename= linkname;
   }
-  else
+  else if (linkname)
   {
-    if (linkname)
-    {
-      if (!realpath(linkname,rp_buff))
-        my_load_path(rp_buff, linkname, NULL);
-      rp_buff[FN_REFLEN-1]= '\0';
-      strcpy(abs_linkname,rp_buff);
-    }
-    create_link= (linkname && strcmp(abs_linkname,filename));
+    if (!realpath(linkname,rp_buff))
+      my_load_path(rp_buff, linkname, NULL);
+    rp_buff[FN_REFLEN-1]= '\0';
+    char abs_linkname[FN_REFLEN];
+    strcpy(abs_linkname, rp_buff);
+    create_link= strcmp(abs_linkname, filename);
   }
 
   if (!(MyFlags & MY_DELETE_OLD))
@@ -76,28 +68,26 @@
     }
   }
 
-  if ((file=my_create(filename, createflags, access_flags, MyFlags)) >= 0)
+  int file= my_create(filename, createflags, access_flags, MyFlags);
+  if (file >= 0 && create_link)
   {
-    if (create_link)
+    /* Delete old link/file */
+    if (MyFlags & MY_DELETE_OLD)
+      my_delete(linkname, MYF(0));
+    /* Create link */
+    if (symlink(filename,linkname))
     {
-      /* Delete old link/file */
-      if (MyFlags & MY_DELETE_OLD)
-	my_delete(linkname, MYF(0));
-      /* Create link */
-      if (symlink(filename,linkname))
-      {
-	/* Fail, remove everything we have done */
-	tmp_errno=errno;
-	my_close(file,MYF(0));
-	my_delete(filename, MYF(0));
-	file= -1;
-	errno=tmp_errno;
-      }
-      else if (MyFlags & MY_SYNC_DIR)
-        my_sync_dir_by_file(linkname, MyFlags);
+      /* Fail, remove everything we have done */
+      int tmp_errno= errno;
+      my_close(file, MYF(0));
+      my_delete(filename, MYF(0));
+      file= -1;
+      errno= tmp_errno;
     }
+    else if (MyFlags & MY_SYNC_DIR)
+      my_sync_dir_by_file(linkname, MyFlags);
   }
-  return(file);
+  return file;
 }
 
 /*

=== modified file 'drizzled/lex_input_stream.h'
--- drizzled/lex_input_stream.h	2011-08-03 10:04:55 +0000
+++ drizzled/lex_input_stream.h	2011-08-08 12:51:19 +0000
@@ -145,9 +145,9 @@
     End of file indicator for the query text to parse.
     @return true if there are no more characters to parse
   */
-  bool eof()
+  bool eof() const
   {
-    return (m_ptr >= m_end_of_query);
+    return m_ptr >= m_end_of_query;
   }
 
   /**
@@ -155,25 +155,25 @@
     @param n number of characters expected
     @return true if there are less than n characters to parse
   */
-  bool eof(int n)
+  bool eof(int n) const
   {
-    return ((m_ptr + n) >= m_end_of_query);
+    return m_ptr + n >= m_end_of_query;
   }
 
   /** Get the raw query buffer. */
-  const char *get_buf()
+  const char *get_buf() const
   {
     return m_buf;
   }
 
   /** Get the pre-processed query buffer. */
-  const char *get_cpp_buf()
+  const char *get_cpp_buf() const
   {
     return m_cpp_buf;
   }
 
   /** Get the end of the raw query buffer. */
-  const char *get_end_of_query()
+  const char *get_end_of_query() const
   {
     return m_end_of_query;
   }

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-07-07 13:41:07 +0000
+++ drizzled/sql_table.cc	2011-08-08 12:51:19 +0000
@@ -2137,16 +2137,13 @@
 
 bool analyze_table(Session* session, TableList* tables)
 {
-  thr_lock_type lock_type = TL_READ_NO_INSERT;
-
-  return(admin_table(session, tables, "analyze", lock_type, true, &Cursor::ha_analyze));
+  return admin_table(session, tables, "analyze", TL_READ_NO_INSERT, true, &Cursor::ha_analyze);
 }
 
 
 bool check_table(Session* session, TableList* tables)
 {
-  thr_lock_type lock_type = TL_READ_NO_INSERT;
-  return admin_table(session, tables, "check", lock_type, false, &Cursor::ha_check);
+  return admin_table(session, tables, "check", TL_READ_NO_INSERT, false, &Cursor::ha_check);
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-07-25 14:24:19 +0000
+++ drizzled/statement/alter_schema.cc	2011-08-08 12:51:19 +0000
@@ -84,9 +84,7 @@
   
   drizzled::message::update(schema_message);
 
-  bool res= schema::alter(session(), schema_message, *old_definition);
-
-  return not res;
+  return not schema::alter(session(), schema_message, *old_definition);
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/table/singular.cc'
--- drizzled/table/singular.cc	2011-07-05 14:36:13 +0000
+++ drizzled/table/singular.cc	2011-08-08 12:51:19 +0000
@@ -126,12 +126,8 @@
 
 bool Singular::open_tmp_table()
 {
-  int error;
-  
   identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getPath());
-  if ((error=cursor->ha_open(identifier,
-                             O_RDWR,
-                             HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE)))
+  if (int error= cursor->ha_open(identifier, O_RDWR, HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE))
   {
     print_error(error, MYF(0));
     db_stat= 0;
@@ -303,17 +299,11 @@
   if (cursor)
   {
     if (db_stat)
-    {
-      cursor->closeMarkForDelete(getShare()->getTableName());
-    }
+      cursor->closeMarkForDelete();
 
     identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getTableName());
     drizzled::error_t ignored;
-    plugin::StorageEngine::dropTable(*in_use,
-                                     *getShare()->getEngine(),
-                                     identifier,
-                                     ignored);
-
+    plugin::StorageEngine::dropTable(*in_use, *getShare()->getEngine(), identifier, ignored);
     delete cursor;
   }
 
@@ -328,6 +318,5 @@
   in_use->set_proc_info(save_proc_info);
 }
 
-
 } /* namespace table */
 } /* namespace drizzled */

=== modified file 'plugin/memory/ha_heap.cc'
--- plugin/memory/ha_heap.cc	2011-07-15 08:26:31 +0000
+++ plugin/memory/ha_heap.cc	2011-08-08 12:51:19 +0000
@@ -621,12 +621,12 @@
    [2  non-unique indexes are disabled - NOT YET IMPLEMENTED]
 */
 
-int ha_heap::indexes_are_disabled(void)
+int ha_heap::indexes_are_disabled()
 {
   return heap_indexes_are_disabled(file);
 }
 
-void ha_heap::drop_table(const char *)
+void ha_heap::drop_table()
 {
   file->getShare()->delete_on_close= 1;
   close();

=== modified file 'plugin/memory/ha_heap.h'
--- plugin/memory/ha_heap.h	2011-03-14 05:40:28 +0000
+++ plugin/memory/ha_heap.h	2011-08-08 12:51:19 +0000
@@ -83,7 +83,7 @@
   drizzled::ha_rows records_in_range(uint32_t inx,
                                      drizzled::key_range *min_key,
                                      drizzled::key_range *max_key);
-  void drop_table(const char *name);
+  void drop_table();
 
   int cmp_ref(const unsigned char *ref1, const unsigned char *ref2);
   int reset_auto_increment(uint64_t value)

